@@ -1,11 +1,11 @@
 #-*- encoding: utf-8 -*-
 
 '''
-Created on 2014年.04.21
+Created on 2014.04.21
 
 global constant here
 
-@author: ZoeAllen
+@author: Allen
 '''
 
 
